==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/gnc/import/gncimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[et]": "Michael Edwardes",
                "Name[eu]": "Michael Edwardes",
                "Name[fi]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[ia]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[ko]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sl]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx",
                "Name[zh_CN]": "Michael Edwardes"
            }
        ],
        "Description": "Add GnuCash importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des del GnuCash al KMyMoney",
        "Description[ca]": "Afegeix la importació des del GnuCash al KMyMoney",
        "Description[de]": "Fügt GnuCash-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add GnuCash importing to KMyMoney",
        "Description[es]": "Añade importación GnuCash a KMyMoney",
        "Description[et]": "KMyMoney GnuCashi importimine",
        "Description[eu]": "GnuCash inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää KMyMoneyyn GnuCash-tuonnin",
        "Description[fr]": "Ajoute l'importation « GnuCash » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar GnuCash en KMyMoney",
        "Description[it]": "Aggiunge l'importazione GnuCash a KMymoney",
        "Description[ko]": "KMyMoney에 GnuCash 가져오기 추가",
        "Description[nl]": "Voeg GnuCash importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie GnuCash do KMyMoney",
        "Description[pt]": "Adição da importação do GnuCash para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação GnuCash no KMyMoney",
        "Description[sk]": "Pridať GnuCash import do KMyMoney",
        "Description[sl]": "Doda uvoz GnuCash v KMyMoney",
        "Description[sv]": "Lägg till GnuCash-import till KMyMoney",
        "Description[uk]": "Імпортування даних GnuCash у KMyMoney",
        "Description[x-test]": "xxAdd GnuCash importing to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 GnuCash 导入服务",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "gncimporter",
        "License": "GPL",
        "Name": "GNC Importer",
        "Name[ca@valencia]": "Importador de GNC",
        "Name[ca]": "Importador de GNC",
        "Name[de]": "GNC-Import",
        "Name[en_GB]": "GNC Importer",
        "Name[es]": "Importador GNC",
        "Name[et]": "GNC importija",
        "Name[eu]": "OFX inportatzailea",
        "Name[fi]": "GNC-tuonti",
        "Name[fr]": "Importateur GNC",
        "Name[gl]": "Importador de GNC",
        "Name[ia]": "Importator de GNC",
        "Name[it]": "Strumento di importazione GNC",
        "Name[ko]": "GNC 가져오기 도구",
        "Name[nl]": "GNC-importprogramma",
        "Name[pl]": "Importer GNC",
        "Name[pt]": "Importação de GNC",
        "Name[pt_BR]": "Importador GNC",
        "Name[ru]": "Импорт GNC",
        "Name[sk]": "GNC Importer",
        "Name[sl]": "Uvoznik GNC",
        "Name[sv]": "GNC-import",
        "Name[uk]": "Імпортування GNC",
        "Name[x-test]": "xxGNC Importerxx",
        "Name[zh_CN]": "GNC 导入工具",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.90.tar.xz: kmymoney-5.1.90/kmymoney/plugins/gnc/import/gncimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[eo]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[et]": "Michael Edwardes",
                "Name[eu]": "Michael Edwardes",
                "Name[fi]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[ia]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[ka]": "Michael Edwardes",
                "Name[ko]": "Michael Edwardes",
                "Name[nb]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sl]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[tr]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx",
                "Name[zh_CN]": "Michael Edwardes",
                "Name[zh_TW]": "Michael Edwardes"
            }
        ],
        "Description": "Add GnuCash importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de GnuCash a KMyMoney",
        "Description[ca]": "Afegeix la importació des del GnuCash al KMyMoney",
        "Description[de]": "Fügt GnuCash-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add GnuCash importing to KMyMoney",
        "Description[eo]": "Aldoni GnuCash-importadon al KMyMoney",
        "Description[es]": "Añade importación GnuCash a KMyMoney",
        "Description[et]": "KMyMoney GnuCashi importimine",
        "Description[eu]": "GnuCash inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää KMyMoneyyn GnuCash-tuonnin",
        "Description[fr]": "Ajoute l'importation « GNUCash » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar GnuCash en KMyMoney",
        "Description[it]": "Aggiunge l'importazione GnuCash a KMymoney",
        "Description[ka]": "KMyMoney-ში GnuCash -ს შემოტანის დამატება",
        "Description[ko]": "KMyMoney에 GnuCash 가져오기 추가",
        "Description[nb]": "Legge til import av GnuCash i KMyMoney",
        "Description[nl]": "Voeg GnuCash importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie GnuCash do KMyMoney",
        "Description[pt]": "Adição da importação do GnuCash para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação GnuCash no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney возможность импорта GnuCash",
        "Description[sk]": "Pridať GnuCash import do KMyMoney",
        "Description[sl]": "Doda uvoz GnuCash v KMyMoney",
        "Description[sv]": "Lägg till GnuCash-import till KMyMoney",
        "Description[tr]": "K Param'a GnuCash içe aktarma ekle",
        "Description[uk]": "Імпортування даних GnuCash у KMyMoney",
        "Description[x-test]": "xxAdd GnuCash importing to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 GnuCash 导入服务",
        "Description[zh_TW]": "提供 GnuCash 匯入功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "gncimporter",
        "License": "GPL",
        "Name": "GNC Importer",
        "Name[ca@valencia]": "Importador de GNC",
        "Name[ca]": "Importador de GNC",
        "Name[de]": "GNC-Import",
        "Name[en_GB]": "GNC Importer",
        "Name[eo]": "GNC Importilo",
        "Name[es]": "Importador GNC",
        "Name[et]": "GNC importija",
        "Name[eu]": "OFX inportatzailea",
        "Name[fi]": "GNC-tuonti",
        "Name[fr]": "Importateur GNC",
        "Name[gl]": "Importador de GNC",
        "Name[ia]": "Importator de GNC",
        "Name[it]": "Strumento di importazione GNC",
        "Name[ka]": "GNC შემომტანი",
        "Name[ko]": "GNC 가져오기 도구",
        "Name[nb]": "GNC-import",
        "Name[nl]": "GNC-importprogramma",
        "Name[pl]": "Importer GNC",
        "Name[pt]": "Importação de GNC",
        "Name[pt_BR]": "Importador GNC",
        "Name[ru]": "Импорт GNC",
        "Name[sk]": "GNC Importer",
        "Name[sl]": "Uvoznik GNC",
        "Name[sv]": "GNC-import",
        "Name[tr]": "GNC İçe Aktarıcısı",
        "Name[uk]": "Імпортування GNC",
        "Name[x-test]": "xxGNC Importerxx",
        "Name[zh_CN]": "GNC 导入工具",
        "Name[zh_TW]": "GNC 匯入工具",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
